"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const sinon = require("sinon");
const nock = require("nock");
const utils = require("../../utils");
const api = require("../../api");
const helpers = require("../helpers");
const removeRemote_1 = require("../../database/removeRemote");
const listRemote_1 = require("../../database/listRemote");
describe("RemoveRemote", () => {
    const instance = "fake-db";
    const remote = new removeRemote_1.RTDBRemoveRemote(instance);
    const listRemote = new listRemote_1.RTDBListRemote(instance);
    const serverUrl = utils.addSubdomain(api.realtimeOrigin, instance);
    let sandbox;
    beforeEach(() => {
        sandbox = sinon.createSandbox();
        helpers.mockAuth(sandbox);
    });
    afterEach(() => {
        sandbox.restore();
        nock.cleanAll();
    });
    it("should return true when patch is small", () => {
        nock(serverUrl)
            .patch("/a/b.json")
            .query({ print: "silent", writeSizeLimit: "tiny" })
            .reply(200, {});
        return chai_1.expect(remote.deletePath("/a/b")).to.eventually.eql(true);
    });
    it("should return false whem patch is large", () => {
        nock(serverUrl)
            .patch("/a/b.json")
            .query({ print: "silent", writeSizeLimit: "tiny" })
            .reply(400, {
            error: "Data requested exceeds the maximum size that can be accessed with a single request.",
        });
        return chai_1.expect(remote.deleteSubPath("/a/b", ["1", "2", "3"])).to.eventually.eql(false);
    });
    it("should return true when multi-path patch is small", () => {
        nock(serverUrl)
            .patch("/a/b.json")
            .query({ print: "silent", writeSizeLimit: "tiny" })
            .reply(200, {});
        return chai_1.expect(remote.deleteSubPath("/a/b", ["1", "2", "3"])).to.eventually.eql(true);
    });
    it("should return false when multi-path patch is large", () => {
        nock(serverUrl)
            .patch("/a/b.json")
            .query({ print: "silent", writeSizeLimit: "tiny" })
            .reply(400, {
            error: "Data requested exceeds the maximum size that can be accessed with a single request.",
        });
        return chai_1.expect(remote.deleteSubPath("/a/b", ["1", "2", "3"])).to.eventually.eql(false);
    });
});
//# sourceMappingURL=removeRemote.spec.js.map